"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.renderRichText = renderRichText;
var _richTextReactRenderer = require("@contentful/rich-text-react-renderer");
function renderRichText({
  json,
  links
}, makeOptions) {
  const options = typeof makeOptions === `function` ? makeOptions(generateLinkMaps(links)) : makeOptions;
  return (0, _richTextReactRenderer.documentToReactComponents)(json, options);
}

/**
 * Helper function to simplify Rich Text rendering. Based on:
 * https://www.contentful.com/blog/2021/04/14/rendering-linked-assets-entries-in-contentful/
 */
function generateLinkMaps(links) {
  var _links$assets, _links$assets2, _links$entries, _links$entries2, _links$entries3;
  const assetBlockMap = new Map();
  if (links !== null && links !== void 0 && (_links$assets = links.assets) !== null && _links$assets !== void 0 && _links$assets.block) {
    for (const asset of links.assets.block) {
      assetBlockMap.set(asset.sys.id, asset);
    }
  }
  const assetHyperlinkMap = new Map();
  if (links !== null && links !== void 0 && (_links$assets2 = links.assets) !== null && _links$assets2 !== void 0 && _links$assets2.hyperlink) {
    for (const asset of links.assets.hyperlink) {
      assetHyperlinkMap.set(asset.sys.id, asset);
    }
  }
  const entryBlockMap = new Map();
  if (links !== null && links !== void 0 && (_links$entries = links.entries) !== null && _links$entries !== void 0 && _links$entries.block) {
    for (const entry of links.entries.block) {
      entryBlockMap.set(entry.sys.id, entry);
    }
  }
  const entryInlineMap = new Map();
  if (links !== null && links !== void 0 && (_links$entries2 = links.entries) !== null && _links$entries2 !== void 0 && _links$entries2.inline) {
    for (const entry of links.entries.inline) {
      entryInlineMap.set(entry.sys.id, entry);
    }
  }
  const entryHyperlinkMap = new Map();
  if (links !== null && links !== void 0 && (_links$entries3 = links.entries) !== null && _links$entries3 !== void 0 && _links$entries3.hyperlink) {
    for (const entry of links.entries.hyperlink) {
      entryHyperlinkMap.set(entry.sys.id, entry);
    }
  }
  return {
    assetBlockMap,
    assetHyperlinkMap,
    entryBlockMap,
    entryInlineMap,
    entryHyperlinkMap
  };
}